diff --git a/CMakeLists.txt b/CMakeLists.txt
new file mode 100644
index 0000000..d63a499
--- /dev/null
+++ b/CMakeLists.txt
@@ -0,0 +1,91 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+cmake_minimum_required( VERSION 2.8 )
+
+
+##### general package setup #####################
+
+project( kdeartwork )
+
+set( PACKAGE kdeartwork )
+set( VERSION "3.5.13" )
+
+
+##### include essential cmake modules ###########
+
+include( FindPkgConfig )
+include( CheckIncludeFile )
+include( CheckIncludeFileCXX )
+include( CheckCXXSourceCompiles )
+
+##### include our cmake modules #################
+
+set( CMAKE_MODULE_PATH "${CMAKE_SOURCE_DIR}/cmake/modules" )
+include( TDEMacros )
+
+
+##### setup install paths #######################
+
+include( TDESetupPaths )
+tde_setup_paths( )
+
+
+##### optional stuff ############################
+
+option( WITH_XSCREENSAVER "Enable xscreensavers support" ON )
+option( WITH_LIBART "Enable libart support" ON )
+option( WITH_OPENGL "Enable 3D GL modes" ON )
+option( WITH_ARTS "Enable aRts support" OFF )
+
+##### user requested modules ####################
+
+option( BUILD_ALL "Build all" OFF )
+option( BUILD_EMOTICONS "Build emoticons" ${BUILD_ALL} )
+option( BUILD_ICEWM_THEMES "Build icewm-themes" ${BUILD_ALL} )
+option( BUILD_ICON_THEMES "Build icon themes" ${BUILD_ALL} )
+option( BUILD_KSCREENSAVER "Build kscreensaver" ${BUILD_ALL} )
+option( BUILD_KWIN_STYLES "Build kwin styles" ${BUILD_ALL} )
+option( BUILD_KWORLDCLOCK "Build kworldclock" ${BUILD_ALL} )
+option( BUILD_SOUNDS "Build sounds" ${BUILD_ALL} )
+option( BUILD_STYLES "Build styles" ${BUILD_ALL} )
+option( BUILD_WALLPAPERS "Build wallpapers" ${BUILD_ALL} )
+
+##### configure checks ##########################
+
+include( ConfigureChecks.cmake )
+
+###### global compiler settings #################
+
+add_definitions(
+  -DHAVE_CONFIG_H
+)
+
+set( CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} ${TQT_CXX_FLAGS}" )
+set( CMAKE_SHARED_LINKER_FLAGS "-Wl,--no-undefined" )
+set( CMAKE_MODULE_LINKER_FLAGS "-Wl,--no-undefined" )
+
+
+##### kdenetwork directories ####################
+
+tde_conditional_add_subdirectory( BUILD_EMOTICONS emoticons )
+tde_conditional_add_subdirectory( BUILD_ICEWM_THEMES icewm-themes )
+tde_conditional_add_subdirectory( BUILD_ICON_THEMES IconThemes )
+tde_conditional_add_subdirectory( BUILD_KSCREENSAVER kscreensaver )
+tde_conditional_add_subdirectory( BUILD_KWIN_STYLES kwin-styles )
+tde_conditional_add_subdirectory( BUILD_KWORLDCLOCK kworldclock )
+tde_conditional_add_subdirectory( BUILD_SOUNDS sounds )
+tde_conditional_add_subdirectory( BUILD_STYLES styles )
+tde_conditional_add_subdirectory( BUILD_WALLPAPERS wallpapers )
+
+##### write configure files #####################
+
+configure_file( config.h.cmake config.h @ONLY )
diff --git a/ConfigureChecks.cmake b/ConfigureChecks.cmake
new file mode 100644
index 0000000..3b3885c
--- /dev/null
+++ b/ConfigureChecks.cmake
@@ -0,0 +1,81 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+if( BUILD_KSCREENSAVER )
+  # limits.h (kscreensaver/kdesavers) 
+  check_include_file_cxx( limits HAVE_NUMERIC_LIMITS )
+  
+  # memory.h (kscreensaver/xsavers) 
+  check_include_file( memory.h HAVE_MEMORY_H )
+
+  # X11/dirent.h (kscreensaver/xsavers)
+  check_include_file( X11/dirent.h HAVE_DIRENT_H )
+
+  # sys/ndir.h (kscreensaver/xsavers)
+  check_include_file( sys/ndir.h HAVE_SYS_NDIR_H )
+
+  # sys/dir.h (kscreensaver/xsavers)
+  check_include_file( sys/dir.h HAVE_SYS_DIR_H )
+
+  # ndir.h (kscreensaver/xsavers)
+  check_include_file( ndir.h HAVE_NDIR_H )
+  
+  # OpenGL(kscreensaver/kdesavers)
+  if( WITH_OPENGL )
+    find_package( OpenGL REQUIRED )
+    if( NOT OPENGL_FOUND )
+      tde_message_fatal( "OpenGL is required, but was not found on your system" )
+    endif( NOT OPENGL_FOUND )
+    
+	# for kscreensaver/xsavers
+	set( HAVE_GL ${OPENGL_FOUND} )
+    
+	# GL/xmesa.h (kscreensaver/xsavers)
+    check_include_file( GL/xmesa.h HAVE_GL_XMESA_H )
+
+    # GL/glut.h (kscreensaver/xsavers)
+    check_include_file( GL/glut.h HAVE_GL_XMESA_H )
+
+  endif( WITH_OPENGL )
+  
+  # libart(kscreensaver/kdesavers)
+  if( WITH_LIBART )
+    pkg_search_module( LIBART libart libart_lgpl libart-2.0 )
+    if( NOT LIBART_FOUND )
+      tde_message_fatal( "libart is required, but was not found on your system" )
+    endif( NOT LIBART_FOUND  )
+  endif( WITH_LIBART )
+  
+  # arts(kscreensaver/kdesavers)
+  if( WITH_ARTS )
+    pkg_search_module( ARTS arts )
+    if( NOT ARTS_FOUND )
+      message( FATAL_ERROR "\naRts is requested, but was not found on your system" )
+    endif( )
+  endif( WITH_ARTS )
+  
+  # xscreensavers(kscreensaver/kxsconfig)
+  if( WITH_XSCREENSAVER )
+    find_package( X11 )
+    if( NOT X11_FOUND OR NOT X11_Xt_FOUND )
+      message( FATAL_ERROR 
+  		"\nX11 and Xt library is required for xscreensaver support, but it was not found on your system" )
+    endif( )
+    include( FindXscreensaver.cmake ) # not really good practise
+    if( NOT XSCREENSAVER_FOUND )
+      message( FATAL_ERROR "\nxscreensaver is requested, but was not found on your system" )
+    endif( )
+  endif( WITH_XSCREENSAVER )
+endif( BUILD_KSCREENSAVER )
+
+# required stuff
+find_package( TQt )
+find_package( TDE )
diff --git a/FindXscreensaver.cmake b/FindXscreensaver.cmake
new file mode 100644
index 0000000..5723609
--- /dev/null
+++ b/FindXscreensaver.cmake
@@ -0,0 +1,82 @@
+#Macro to find xscreensaver directory
+
+# Copyright (c) 2006, Laurent Montel, <montel@kde.org>
+#
+# Redistribution and use is allowed according to the terms of the BSD license.
+# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# got from kde4
+
+if (NOT XSCREENSAVER_FOUND)
+  set(xscreensaver_alldirs)
+  set(xscreensaver_checkdirs ${TDE_INCLUDE_DIR}
+   	/usr/
+	/usr/local/
+   	/opt/local/
+   	/usr/X11R6/
+   	/opt/kde/
+   	/opt/kde3/
+   	/usr/kde/
+   	/usr/local/kde/
+   	/usr/local/xscreensaver/
+   	/usr/openwin/lib/xscreensaver/
+   	/etc/ )
+  foreach(suffix lib${LIB_SUFFIX}/xscreensaver lib${LIB_SUFFIX}/misc/xscreensaver lib/xscreensaver lib64/xscreensaver libexec/xscreensaver 
+bin/xscreensaver-hacks hacks)
+     foreach(xscreensaver_path ${xscreensaver_checkdirs} )
+        set(xscreensaver_alldirs ${xscreensaver_alldirs} ${xscreensaver_path}/${suffix})
+     endforeach(xscreensaver_path ${xscreensaver_checkdirs} )
+  endforeach(suffix lib${LIB_SUFFIX}/xscreensaver lib/xscreensaver lib64/xscreensaver libexec/xscreensaver bin/xscreensaver-hacks hacks)
+  FIND_PATH(XSCREENSAVER_DIR deco ${xscreensaver_alldirs})
+
+  set(XSCREENSAVER_CONFIG_DIR)
+  FIND_PATH(XSCREENSAVER_CONFIG_DECO config/deco.xml
+    ${TDE_INCLUDE_DIR}
+    /usr/
+    /usr/local/
+    /opt/local/
+    /usr/X11R6/
+    /opt/kde/
+    /opt/kde3/
+    /usr/kde/
+    /usr/share/xscreensaver/
+    /usr/local/kde/
+    /usr/local/xscreensaver/
+    /usr/openwin/lib/xscreensaver/
+    /etc/
+  )
+  #MESSAGE(STATUS "XSCREENSAVER_CONFIG_DIR :<${XSCREENSAVER_CONFIG_DIR}>")
+
+  if(XSCREENSAVER_CONFIG_DECO)
+	set(XSCREENSAVER_CONFIG_DIR "${XSCREENSAVER_CONFIG_DECO}/config/")
+	#MESSAGE(STATUS "XSCREENSAVER_CONFIG_DIR <${XSCREENSAVER_CONFIG_DIR}>")
+  endif(XSCREENSAVER_CONFIG_DECO)
+
+
+  # Try and locate XScreenSaver config when path doesn't include config
+  if(NOT XSCREENSAVER_CONFIG_DIR)
+    FIND_PATH(XSCREENSAVER_CONFIG_DIR deco.xml
+      /etc/xscreensaver
+      )
+  endif(NOT XSCREENSAVER_CONFIG_DIR)
+endif(NOT XSCREENSAVER_FOUND)
+
+#MESSAGE(STATUS "XSCREENSAVER_CONFIG_DIR :<${XSCREENSAVER_CONFIG_DIR}>")
+#MESSAGE(STATUS "XSCREENSAVER_DIR :<${XSCREENSAVER_DIR}>")
+
+# Need to fix hack
+if(XSCREENSAVER_DIR AND XSCREENSAVER_CONFIG_DIR)
+	set(XSCREENSAVER_FOUND TRUE)
+endif(XSCREENSAVER_DIR AND XSCREENSAVER_CONFIG_DIR)
+
+if (XSCREENSAVER_FOUND)
+  if (NOT Xscreensaver_FIND_QUIETLY)
+    message(STATUS "Found SCREENSAVER_CONFIG_DIR <${XSCREENSAVER_CONFIG_DIR}>")
+  endif (NOT Xscreensaver_FIND_QUIETLY)
+else (XSCREENSAVER_FOUND)
+  if (Xscreensaver_FIND_REQUIRED)
+    message(FATAL_ERROR "XScreenSaver not found")
+  endif (Xscreensaver_FIND_REQUIRED)
+endif (XSCREENSAVER_FOUND)
+
+
+MARK_AS_ADVANCED(XSCREENSAVER_DIR XSCREENSAVER_CONFIG_DIR)
diff --git a/IconThemes/CMakeLists.txt b/IconThemes/CMakeLists.txt
new file mode 100644
index 0000000..75f55d2
--- /dev/null
+++ b/IconThemes/CMakeLists.txt
@@ -0,0 +1,28 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+set(ICON_THEMES Locolor ikons kdeclassic slick kids )
+set(ICON_TYPES actions apps devices filesystems mimetypes)
+set(ICON_SIZES 16x16 22x22 32x32 48x48 64x64 128x128 scalable)
+set(ICON_SUFFIXES png mng svg svgz)
+
+foreach (theme ${ICON_THEMES})
+  install(FILES ${theme}/index.theme DESTINATION ${ICON_INSTALL_DIR}/${theme} )
+  foreach(size ${ICON_SIZES})
+    foreach(type ${ICON_TYPES})
+      foreach(suffix ${ICON_SUFFIXES})
+        FILE(GLOB files  "${theme}/${size}/${type}/*.${suffix}" )
+        install(FILES ${files} DESTINATION ${ICON_INSTALL_DIR}/${theme}/${size}/${type}/)
+      endforeach(suffix ${ICON_SUFFIXES})
+    endforeach(type ${ICON_TYPES})
+  endforeach(size ${ICON_SIZES})
+endforeach (theme ${ICON_THEMES})
+
diff --git a/config.h.cmake b/config.h.cmake
new file mode 100644
index 0000000..1749551
--- /dev/null
+++ b/config.h.cmake
@@ -0,0 +1,34 @@
+#define VERSION "@VERSION@"
+
+#cmakedefine HAVE_NUMERIC_LIMITS 1
+
+/* Defines where xscreensaver stores it's config files */
+#define XSCREENSAVER_CONFIG_DIR "@XSCREENSAVER_CONFIG_DIR@"
+
+/* Defines where xscreensaver stores its graphic hacks */
+#define XSCREENSAVER_HACKS_DIR "@XSCREENSAVER_DIR@"
+
+/* Defines if you have GL (Mesa, OpenGL, ...) */
+#cmakedefine HAVE_GL 1
+
+/* Defines if you have GL/xmesa.h header file. */
+#cmakedefine HAVE_GL_XMESA_H 1
+
+/* Defines if you have GL/glut.h header file. */
+#cmakedefine HAVE_GL_XMESA_H 1
+
+/* Defines if you have X11/dirent.h header file. */
+#cmakedefine HAVE_DIRENT_H 1
+
+/* Defines if you have sys/ndir.h header file. */
+#cmakedefine HAVE_SYS_NDIR_H 1
+
+/* Defines if you have sys/dir.h header file. */
+#cmakedefine HAVE_SYS_DIR_H 1
+
+/* Defines if you have ndir.h header file. */
+#cmakedefine HAVE_NDIR_H 1
+
+/* Define to 1 if you have the <memory.h> header file. */
+#cmakedefine HAVE_MEMORY_H 1
+
diff --git a/emoticons/BoxedEmoticonSet/CMakeLists.txt b/emoticons/BoxedEmoticonSet/CMakeLists.txt
new file mode 100644
index 0000000..7366116
--- /dev/null
+++ b/emoticons/BoxedEmoticonSet/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml
+    angry.png bigsmile.png confused.png cry.png
+    oh.png sad.png shade.png smile.png tongue.png
+    wink.png
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/Boxed )
diff --git a/emoticons/CMakeLists.txt b/emoticons/CMakeLists.txt
new file mode 100644
index 0000000..f0a3240
--- /dev/null
+++ b/emoticons/CMakeLists.txt
@@ -0,0 +1,23 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( BoxedEmoticonSet )
+add_subdirectory( ccmathteam.com )
+add_subdirectory( greggman.com )
+add_subdirectory( GroupWise )
+add_subdirectory( KMess )
+add_subdirectory( KMess-Blue )
+add_subdirectory( KMess-Cartoon )
+add_subdirectory( KMess-Violet )
+add_subdirectory( phpBB )
+add_subdirectory( plain )
+add_subdirectory( redones )
+add_subdirectory( set1 )
diff --git a/emoticons/GroupWise/CMakeLists.txt b/emoticons/GroupWise/CMakeLists.txt
new file mode 100644
index 0000000..282aba4
--- /dev/null
+++ b/emoticons/GroupWise/CMakeLists.txt
@@ -0,0 +1,14 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml 
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/GroupWise )
diff --git a/emoticons/KMess-Blue/CMakeLists.txt b/emoticons/KMess-Blue/CMakeLists.txt
new file mode 100644
index 0000000..c76e67c
--- /dev/null
+++ b/emoticons/KMess-Blue/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml
+    angry.png confused.png cry.png
+    embarassed.png omg.png sad.png
+    shade.png smile.png teeth.png
+    tongue.png wink.png
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/KMess-Blue )
diff --git a/emoticons/KMess-Cartoon/CMakeLists.txt b/emoticons/KMess-Cartoon/CMakeLists.txt
new file mode 100644
index 0000000..c79bedc
--- /dev/null
+++ b/emoticons/KMess-Cartoon/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml
+    angel.png angry.png confused.png cry.png
+	devil.png embarrassed.png omg.png sad.png
+	shade.png smile.png teeth.png tongue.png
+	ugly.png wink.png  
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/KMess-Cartoon )
diff --git a/emoticons/KMess-Violet/CMakeLists.txt b/emoticons/KMess-Violet/CMakeLists.txt
new file mode 100644
index 0000000..64cd519
--- /dev/null
+++ b/emoticons/KMess-Violet/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml
+    angry.png confused.png cry.png
+    embarassed.png omg.png sad.png
+    shade.png smile.png teeth.png
+    tongue.png wink.png 
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/KMess-Violet )
diff --git a/emoticons/KMess/CMakeLists.txt b/emoticons/KMess/CMakeLists.txt
new file mode 100644
index 0000000..5492d04
--- /dev/null
+++ b/emoticons/KMess/CMakeLists.txt
@@ -0,0 +1,26 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml
+    angel.png angry.png bat.png beer.png 
+	boy.png cake.png camera.png cat.png
+	clock.png cocktail.png confused.png
+	cry.png cup.png	devil.png dog.png
+	dude_hug.png embarassed.png	email.png
+	film.png girl.png girl_hug.png kiss.png
+	lightbulb.png love.png messenger.png
+	note.png omg.png phone.png present.png
+	rose.png sad.png shade.png smile.png
+	star.png teeth.png thumbs_down.png
+	thumbs_up.png tongue.png unlove.png
+	wilted_rose.png wink.png
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/KMess )
diff --git a/emoticons/ccmathteam.com/CMakeLists.txt b/emoticons/ccmathteam.com/CMakeLists.txt
new file mode 100644
index 0000000..00a7504
--- /dev/null
+++ b/emoticons/ccmathteam.com/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    emoticons.xml
+    biggrin.png confused.png cry.png devil.png
+    oh.png smile.png sunglasses.png tongue.png
+    unhappy.png wink.png 
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/ccmathteam.com )
diff --git a/emoticons/greggman.com/CMakeLists.txt b/emoticons/greggman.com/CMakeLists.txt
new file mode 100644
index 0000000..c02e35d
--- /dev/null
+++ b/emoticons/greggman.com/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+	emoticons.xml
+    biggrin.png confused.png kiss.png oh.png
+	smile.png sunglasses.png tongue.png unhappy.png
+	vampire.png wink.png 
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/greggman.com )
diff --git a/emoticons/phpBB/CMakeLists.txt b/emoticons/phpBB/CMakeLists.txt
new file mode 100644
index 0000000..d119239
--- /dev/null
+++ b/emoticons/phpBB/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+	emoticons.xml
+    biggrin.png confused.png cry.png devil.png
+	oh.png smile.png sunglasses.png tongue.png
+	unhappy.png wink.png 
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/phpBB )
diff --git a/emoticons/plain/CMakeLists.txt b/emoticons/plain/CMakeLists.txt
new file mode 100644
index 0000000..d88c917
--- /dev/null
+++ b/emoticons/plain/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+	emoticons.xml
+    biggrin.png confused.png cry.png oh.png
+	smile.png sunglasses.png tongue.png
+	unhappy.png wink.png pig.png 
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/Plain )
diff --git a/emoticons/redones/CMakeLists.txt b/emoticons/redones/CMakeLists.txt
new file mode 100644
index 0000000..bfc27cd
--- /dev/null
+++ b/emoticons/redones/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+	emoticons.xml
+    angel.png biggrin.png confused.png cry.png
+	oh.png smile.png sunglasses.png tongue.png
+	unhappy.png wink.png
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/RedOnes )
diff --git a/emoticons/set1/CMakeLists.txt b/emoticons/set1/CMakeLists.txt
new file mode 100644
index 0000000..b8575ce
--- /dev/null
+++ b/emoticons/set1/CMakeLists.txt
@@ -0,0 +1,16 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+	emoticons.xml
+    biggrin.png cry.png oh.png sleep.png smile.png 
+    tongue.png unhappy.png wink.png
+  DESTINATION ${SHARE_INSTALL_PREFIX}/emoticons/tweakers.net )
diff --git a/icewm-themes/CMakeLists.txt b/icewm-themes/CMakeLists.txt
new file mode 100644
index 0000000..7716db2
--- /dev/null
+++ b/icewm-themes/CMakeLists.txt
@@ -0,0 +1,13 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( MenschMaschine )
+add_subdirectory( Model )
\ No newline at end of file
diff --git a/icewm-themes/MenschMaschine/CMakeLists.txt b/icewm-themes/MenschMaschine/CMakeLists.txt
new file mode 100644
index 0000000..b148775
--- /dev/null
+++ b/icewm-themes/MenschMaschine/CMakeLists.txt
@@ -0,0 +1,26 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    closeA.xpm closeI.xpm frameAB.xpm
+	frameABL.xpm frameABR.xpm frameAL.xpm
+	frameAR.xpm frameAT.xpm frameATL.xpm
+	frameATR.xpm frameIB.xpm frameIBL.xpm
+	frameIBR.xpm frameIL.xpm frameIR.xpm
+	frameIT.xpm frameITL.xpm frameITR.xpm
+	maximizeA.xpm maximizeI.xpm menuButtonA.xpm
+	menuButtonI.xpm minimizeA.xpm minimizeI.xpm
+	restoreA.xpm restoreI.xpm titleAB.xpm
+	titleAL.xpm titleAM.xpm titleAR.xpm
+	titleAT.xpm titleIB.xpm titleIL.xpm
+	titleIM.xpm titleIR.xpm titleIT.xpm
+	default.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/icewm-themes/MenschMaschine )
diff --git a/icewm-themes/Model/CMakeLists.txt b/icewm-themes/Model/CMakeLists.txt
new file mode 100644
index 0000000..8759da4
--- /dev/null
+++ b/icewm-themes/Model/CMakeLists.txt
@@ -0,0 +1,25 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    closeA.xpm closeI.xpm frameAB.xpm
+	frameABL.xpm frameABR.xpm frameAL.xpm
+	frameAR.xpm frameAT.xpm frameATL.xpm
+	frameATR.xpm frameIB.xpm frameIBL.xpm
+	frameIBR.xpm frameIL.xpm frameIR.xpm 
+	frameIT.xpm frameITL.xpm frameITR.xpm 
+	maximizeA.xpm maximizeI.xpm menuButtonA.xpm
+	menuButtonI.xpm minimizeA.xpm minimizeI.xpm
+	restoreA.xpm restoreI.xpm titleAB.xpm
+	titleAL.xpm titleAM.xpm titleAT.xpm 
+	titleIB.xpm titleIL.xpm titleIM.xpm 
+	titleIT.xpm default.theme
+DESTINATION ${DATA_INSTALL_DIR}/kwin/icewm-themes/Model )
diff --git a/kscreensaver/CMakeLists.txt b/kscreensaver/CMakeLists.txt
new file mode 100644
index 0000000..0c453ad
--- /dev/null
+++ b/kscreensaver/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( kdesavers )
+add_subdirectory( kpartsaver)
+if( WITH_XSCREENSAVER )
+  add_subdirectory( kxsconfig )
+  add_subdirectory( xsavers )
+endif( WITH_XSCREENSAVER )
diff --git a/kscreensaver/kdesavers/CMakeLists.txt b/kscreensaver/kdesavers/CMakeLists.txt
new file mode 100644
index 0000000..3a74df9
--- /dev/null
+++ b/kscreensaver/kdesavers/CMakeLists.txt
@@ -0,0 +1,145 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${CMAKE_CURRENT_SOURCE_DIR}
+  ${CMAKE_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+  ${TDE_LIB_DIR}
+)
+
+# ##### The "normal" screensavers ###############
+
+set( kbanner_SOURCES    banner.cpp )
+set( kbanner_DESKTOP    KBanner.desktop )
+set( kpolygon_SOURCES   polygon.cpp )
+set( kpolygon_DESKTOP   KPolygon.desktop )
+set( klines_SOURCES     lines.cpp )
+set( klines_DESKTOP     KLines-saver.desktop )
+set( klorenz_SOURCES    lorenz.cpp )
+set( klorenz_DESKTOP    KLorenz.desktop )
+set( kslideshow_SOURCES slideshow.cpp slideshowcfg.ui )
+set( kslideshow_DESKTOP KSlideshow.desktop )
+set( kblob_SOURCES      blob.cpp )
+set( kblob_DESKTOP      KBlob.desktop )
+set( kvm_SOURCES        kvm.cpp vm.c vm_random.c )
+set( kvm_DESKTOP        KVm.desktop )
+
+set( kslideshow_LINK	kio-shared )
+
+set( NORMAL_SCREENSAVERS 
+	kbanner kpolygon kslideshow	klines klorenz kblob kvm )
+
+##### X11 screensavers ##########################
+
+set( kscience_SOURCES   science.cpp )	
+set( kscience_DESKTOP   KScience.desktop )
+
+set( X11_SCREENSAVERS kscience)
+
+##### The GL screensavers #######################
+
+set( kfountain_SOURCES  fountain.cpp fountaincfg.ui )
+set( kfountain_DESKTOP  KFountain.desktop )
+set( kwave_SOURCES      wave.cpp wavecfg.ui )
+set( kwave_DESKTOP      KWave.desktop )
+set( kgravity_SOURCES   gravity.cpp gravitycfg.ui )
+set( kgravity_DESKTOP   KGravity.desktop )
+set( kflux_SOURCES      Flux.cpp )
+set( kflux_DESKTOP      KFlux.desktop )
+set( keuphoria_SOURCES  Euphoria.cpp )
+set( keuphoria_DESKTOP  KEuphoria.desktop )
+set( ksolarwinds_SOURCES SolarWinds.cpp )
+set( ksolarwinds_DESKTOP KSolarWinds.desktop )
+set( krotation_SOURCES  rotation.cpp rotationcfg.ui sspreviewarea.cpp
+   	rkodesolver.cpp vec3.cpp )
+set( krotation_DESKTOP  KRotation.desktop )
+set( kpendulum_SOURCES  pendulum.cpp pendulumcfg.ui sspreviewarea.cpp
+   	rkodesolver.cpp )
+set( kpendulum_DESKTOP  KPendulum.desktop )
+set( OPENGL_SCREENSAVERS kfountain kwave kgravity kflux keuphoria ksolarwinds
+	krotation kpendulum )
+
+##### The GL-Arts screensavers ##################
+
+set( kfiresaver_SOURCES firesaversetup.ui firesaverparticle.cpp
+   	firesaverwriter.cpp	firesaver.cpp )
+set( kfiresaver_DESKTOP KFiresaver.desktop )
+set( kfiresaver_LINK artskde-shared )
+set( GL_ARTS_SCREENSAVERS kfiresaver )
+
+##### The LIBART screensavers ###################
+
+set( kclock_SOURCES	kclock.cpp )
+set( kclock_DESKTOP	KClock.desktop )
+
+set( LIBART_SCREENSAVERS kclock )
+
+##### LIBART conditions #########################
+
+if( WITH_LIBART )
+  list( APPEND SCREENSAVERS ${LIBART_SCREENSAVERS} )
+
+  include_directories( ${LIBART_INCLUDE_DIRS} )
+  link_directories( ${LIBART_LIBRARY_DIRS} )
+  foreach( saver ${LIBART_SCREENSAVERS} )
+    list ( APPEND ${saver}_LINK ${LIBART_LIBRARIES} )
+  endforeach( saver ${LIBART_SCREENSAVERS} )
+endif( WITH_LIBART )
+
+##### GL conditions #############################
+
+if( WITH_OPENGL )
+  if( WITH_ARTS )
+    list( APPEND OPENGL_SCREENSAVERS ${GL_ARTS_SCREENSAVERS} )
+  endif( WITH_ARTS )
+
+  list( APPEND SCREENSAVERS ${OPENGL_SCREENSAVERS} )
+  
+  include_directories( ${OPENGL_INCLUDE_DIRS} )
+  link_directories( ${OPENGL_LIBRARY_DIRS} )
+  foreach( saver ${OPENGL_SCREENSAVERS} )
+    list ( APPEND ${saver}_LINK ${OPENGL_LIBRARIES} )
+  endforeach( saver ${OPENGL_SCREENSAVERS} )
+    
+endif( WITH_OPENGL )
+
+##### add normal screensavers ###################
+
+# FIXME: check for X includes/libraries
+#        this screensavers will work only in X
+list( APPEND SCREENSAVERS ${X11_SCREENSAVERS} )
+list( APPEND SCREENSAVERS ${NORMAL_SCREENSAVERS} )
+	
+##### create install/compile rules ##############
+foreach( saver ${SCREENSAVERS} )
+  tde_add_executable( ${saver}.kss AUTOMOC
+    SOURCES ${${saver}_SOURCES}
+    LINK kscreensaver-shared kdeui-shared ${${saver}_LINK}
+    DESTINATION ${BIN_INSTALL_DIR}
+  )
+  install( FILES ${${saver}_DESKTOP} 
+    DESTINATION ${APPS_INSTALL_DIR}/System/ScreenSavers )
+endforeach( saver ${SCREENSAVERS} )
+
+##### install various data ######################
+
+install( FILES image.png kscience.png particle.png
+    DESTINATION ${DATA_INSTALL_DIR}/kscreensaver )
+
+# Actually the only screensaver tha uses this data is kfiresaver 
+add_subdirectory( data )
diff --git a/kscreensaver/kdesavers/data/CMakeLists.txt b/kscreensaver/kdesavers/data/CMakeLists.txt
new file mode 100644
index 0000000..c9718d9
--- /dev/null
+++ b/kscreensaver/kdesavers/data/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    kfs_particle.png kfs_particle_flare.png
+	kfs_particle_diastar.png kfs_kde.png 
+	kfs_tux.png kfs_letters1.png kfs_letters2.png 
+	kfs_letters.desc kfs_explode.ogg kfs_debris.ogg 
+	DESTINATION ${DATA_INSTALL_DIR}/kfiresaver )
diff --git a/kscreensaver/kpartsaver/CMakeLists.txt b/kscreensaver/kpartsaver/CMakeLists.txt
new file mode 100644
index 0000000..b546c5d
--- /dev/null
+++ b/kscreensaver/kpartsaver/CMakeLists.txt
@@ -0,0 +1,33 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### desktop files #############################
+
+install( FILES kpartsaver.desktop 
+    DESTINATION ${APPS_INSTALL_DIR}/System/ScreenSavers )
+
+##### kpart_cde ##################################
+
+tde_add_executable( kpartsaver.kss AUTOMOC
+  SOURCES kpartsaver.cpp configwidget.ui
+  LINK kscreensaver-shared kio-shared
+  DESTINATION ${BIN_INSTALL_DIR}
+)
diff --git a/kscreensaver/kxsconfig/CMakeLists.txt b/kscreensaver/kxsconfig/CMakeLists.txt
new file mode 100644
index 0000000..99f44e5
--- /dev/null
+++ b/kscreensaver/kxsconfig/CMakeLists.txt
@@ -0,0 +1,66 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${CMAKE_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+  ${X11_INCLUDE_DIR}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+  ${X11_LIBRARY_DIR}
+)
+
+##### kxsconfig #################################
+set( target kxsconfig )
+
+set( ${target}_SRCS
+   kxscontrol.cpp kxsitem.cpp kxsxml.cpp kxsconfig.cpp )
+
+tde_add_executable( ${target} AUTOMOC
+  SOURCES ${${target}_SRCS}
+  LINK kio-shared ${X11_Xt_LIB}
+  DESTINATION ${BIN_INSTALL_DIR}
+)
+
+##### kxsrun ####################################
+set( target kxsrun )
+
+set( ${target}_SRCS
+   kxsrun.cpp kxscontrol.cpp kxsitem.cpp kxsxml.cpp )
+
+tde_add_executable( ${target} AUTOMOC
+  SOURCES ${${target}_SRCS}
+  LINK kio-shared
+  DESTINATION ${BIN_INSTALL_DIR}
+)
+
+##### install desktops ##########################
+# code from kde4
+FILE(GLOB _desktopfiles "ScreenSavers/*.desktop" )
+foreach(_currentdesktopfile ${_desktopfiles})
+  STRING(REGEX REPLACE ".desktop" "" _newitem "${_currentdesktopfile}" )
+  #MESSAGE(STATUS "newItem <${_newitem}>")
+  GET_FILENAME_COMPONENT(_screensaverName ${_newitem} NAME_WE)
+  #MESSAGE(STATUS "name without extension
+  find_file(XSCREENSAVER_FILE_FOUND ${_screensaverName}.xml PATHS ${XSCREENSAVER_CONFIG_DIR} )
+  if(XSCREENSAVER_FILE_FOUND)
+    MESSAGE(STATUS "xscreensaver name ${_screensaverName} found")
+    install(FILES ${_currentdesktopfile} DESTINATION  ${APPS_INSTALL_DIR}/System/ScreenSavers )
+  else(XSCREENSAVER_FILE_FOUND)
+    MESSAGE(STATUS "xscreensaver name ${_screensaverName} not found")
+  endif(XSCREENSAVER_FILE_FOUND)
+  unset(XSCREENSAVER_FILE_FOUND CACHE)
+endforeach(_currentdesktopfile ${_desktopfiles})
+
diff --git a/kscreensaver/xsavers/CMakeLists.txt b/kscreensaver/xsavers/CMakeLists.txt
new file mode 100644
index 0000000..8cbd8fa
--- /dev/null
+++ b/kscreensaver/xsavers/CMakeLists.txt
@@ -0,0 +1,52 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${CMAKE_BINARY_DIR}
+  ${TQT_INCLUDE_DIRS}
+  ${TDE_INCLUDE_DIR}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### shared source ##########################
+
+set( BASE_SRCS main.cpp demowin.cpp saver.cpp helpers.cpp )
+set( XL_SRCS xlock.cpp )
+
+##### kswarm #################################
+
+tde_add_executable( kswarm.kss AUTOMOC
+  SOURCES swarm.cpp ${BASE_SRCS} ${XL_SRCS}
+  LINK kdeui-shared
+  DESTINATION ${BIN_INSTALL_DIR}
+)
+
+install( FILES KSwarm.desktop DESTINATION ${APPS_INSTALL_DIR}/System/ScreenSavers )
+
+##### kswarm #################################
+
+if( WITH_OPENGL )
+  include_directories( ${OPENGL_INCLUDE_DIRS} )
+  link_directories( ${OPENGL_LIBRARY_DIRS} )
+  tde_add_executable( kspace.kss AUTOMOC
+    SOURCES space.cpp ${BASE_SRCS} ${XL_SRCS}
+	LINK kdeui-shared ${OPENGL_LIBRARIES}
+    DESTINATION ${BIN_INSTALL_DIR}
+  )
+  
+  install( FILES KSpace.desktop DESTINATION ${APPS_INSTALL_DIR}/System/ScreenSavers )
+endif( WITH_OPENGL )
+
+
diff --git a/kwin-styles/CMakeLists.txt b/kwin-styles/CMakeLists.txt
new file mode 100644
index 0000000..7f3a583
--- /dev/null
+++ b/kwin-styles/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include( "${TDE_CMAKE_DIR}/kwin.cmake" )
+
+add_subdirectory( cde )
+add_subdirectory( glow )
+add_subdirectory( icewm )
+add_subdirectory( kde1 )
+add_subdirectory( kstep )
+add_subdirectory( openlook )
+add_subdirectory( riscos )
+add_subdirectory( smooth-blend )
+add_subdirectory( system )
diff --git a/kwin-styles/cde/CMakeLists.txt b/kwin-styles/cde/CMakeLists.txt
new file mode 100644
index 0000000..cc24e73
--- /dev/null
+++ b/kwin-styles/cde/CMakeLists.txt
@@ -0,0 +1,34 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( config )
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES cde.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_cde ##################################
+
+tde_add_kpart( kwin3_cde AUTOMOC
+  SOURCES cdeclient.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/cde/config/CMakeLists.txt b/kwin-styles/cde/config/CMakeLists.txt
new file mode 100644
index 0000000..5c5427b
--- /dev/null
+++ b/kwin-styles/cde/config/CMakeLists.txt
@@ -0,0 +1,28 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### kwin_cde_config (module) ###################
+
+tde_add_kpart( kwin_cde_config AUTOMOC
+  SOURCES config.cpp
+  LINK kdeui-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/glow/CMakeLists.txt b/kwin-styles/glow/CMakeLists.txt
new file mode 100644
index 0000000..50b2330
--- /dev/null
+++ b/kwin-styles/glow/CMakeLists.txt
@@ -0,0 +1,35 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( config )
+add_subdirectory( themes )
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES glow.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_glow ################################
+
+tde_add_kpart( kwin3_glow AUTOMOC
+  SOURCES glowbutton.cpp glowclient.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/glow/config/CMakeLists.txt b/kwin-styles/glow/config/CMakeLists.txt
new file mode 100644
index 0000000..d40532a
--- /dev/null
+++ b/kwin-styles/glow/config/CMakeLists.txt
@@ -0,0 +1,28 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### kwin_glow_config (module) ##################
+
+tde_add_kpart( kwin_glow_config AUTOMOC
+  SOURCES glowconfigdialog.cpp
+  LINK kdeui-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/glow/themes/CMakeLists.txt b/kwin-styles/glow/themes/CMakeLists.txt
new file mode 100644
index 0000000..2f72521
--- /dev/null
+++ b/kwin-styles/glow/themes/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( default )
+add_subdirectory( glass )
+add_subdirectory( glass_huge )
+add_subdirectory( glass_large )
+add_subdirectory( glass_verylarge )
+add_subdirectory( square )
\ No newline at end of file
diff --git a/kwin-styles/glow/themes/default/CMakeLists.txt b/kwin-styles/glow/themes/default/CMakeLists.txt
new file mode 100644
index 0000000..f7d98c0
--- /dev/null
+++ b/kwin-styles/glow/themes/default/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    background.png
+    help.png help_glow.png
+    close.png close_glow.png
+    iconify.png iconify_glow.png
+    maximizeoff.png maximizeoff_glow.png
+    maximizeon.png maximizeon_glow.png
+    stickyon.png stickyon_glow.png
+    stickyoff.png stickyoff_glow.png
+    default.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/glow-themes/default )
diff --git a/kwin-styles/glow/themes/glass/CMakeLists.txt b/kwin-styles/glow/themes/glass/CMakeLists.txt
new file mode 100644
index 0000000..bb02a73
--- /dev/null
+++ b/kwin-styles/glow/themes/glass/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    background.png
+    help.png help_glow.png
+    close.png close_glow.png
+    iconify.png iconify_glow.png
+    maximizeoff.png maximizeoff_glow.png
+    maximizeon.png maximizeon_glow.png
+    stickyon.png stickyon_glow.png
+    stickyoff.png stickyoff_glow.png
+    glass.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/glow-themes/glass )
diff --git a/kwin-styles/glow/themes/glass_huge/CMakeLists.txt b/kwin-styles/glow/themes/glass_huge/CMakeLists.txt
new file mode 100644
index 0000000..cd98469
--- /dev/null
+++ b/kwin-styles/glow/themes/glass_huge/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    background.png
+    help.png help_glow.png
+    close.png close_glow.png
+    iconify.png iconify_glow.png
+    maximizeoff.png maximizeoff_glow.png
+    maximizeon.png maximizeon_glow.png
+    stickyon.png stickyon_glow.png
+    stickyoff.png stickyoff_glow.png
+    glass_huge.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/glow-themes/glass_huge )
diff --git a/kwin-styles/glow/themes/glass_large/CMakeLists.txt b/kwin-styles/glow/themes/glass_large/CMakeLists.txt
new file mode 100644
index 0000000..7907f6e
--- /dev/null
+++ b/kwin-styles/glow/themes/glass_large/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    background.png
+    help.png help_glow.png
+    close.png close_glow.png
+    iconify.png iconify_glow.png
+    maximizeoff.png maximizeoff_glow.png
+    maximizeon.png maximizeon_glow.png
+    stickyon.png stickyon_glow.png
+    stickyoff.png stickyoff_glow.png
+    glass_large.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/glow-themes/glass_large )
diff --git a/kwin-styles/glow/themes/glass_verylarge/CMakeLists.txt b/kwin-styles/glow/themes/glass_verylarge/CMakeLists.txt
new file mode 100644
index 0000000..673e16a
--- /dev/null
+++ b/kwin-styles/glow/themes/glass_verylarge/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    background.png
+    help.png help_glow.png
+    close.png close_glow.png
+    iconify.png iconify_glow.png
+    maximizeoff.png maximizeoff_glow.png
+    maximizeon.png maximizeon_glow.png
+    stickyon.png stickyon_glow.png
+    stickyoff.png stickyoff_glow.png
+    glass_verylarge.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/glow-themes/glass_verylarge )
diff --git a/kwin-styles/glow/themes/square/CMakeLists.txt b/kwin-styles/glow/themes/square/CMakeLists.txt
new file mode 100644
index 0000000..26ea9ea
--- /dev/null
+++ b/kwin-styles/glow/themes/square/CMakeLists.txt
@@ -0,0 +1,22 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    background.png
+    help.png help_glow.png
+    close.png close_glow.png
+    iconify.png iconify_glow.png
+    maximizeoff.png maximizeoff_glow.png
+    maximizeon.png maximizeon_glow.png
+    stickyon.png stickyon_glow.png
+    stickyoff.png stickyoff_glow.png
+    square.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/glow-themes/square )
diff --git a/kwin-styles/icewm/CMakeLists.txt b/kwin-styles/icewm/CMakeLists.txt
new file mode 100644
index 0000000..0766fd5
--- /dev/null
+++ b/kwin-styles/icewm/CMakeLists.txt
@@ -0,0 +1,35 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( config )
+add_subdirectory( icewm-themes )
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES icewm.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_icewm ###############################
+
+tde_add_kpart( kwin3_icewm AUTOMOC
+  SOURCES icewm.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/icewm/config/CMakeLists.txt b/kwin-styles/icewm/config/CMakeLists.txt
new file mode 100644
index 0000000..479c84a
--- /dev/null
+++ b/kwin-styles/icewm/config/CMakeLists.txt
@@ -0,0 +1,28 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### kwin_icewm_config (module) ################
+
+tde_add_kpart( kwin_icewm_config AUTOMOC
+  SOURCES config.cpp
+  LINK kdeui-shared kio-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/icewm/icewm-themes/CMakeLists.txt b/kwin-styles/icewm/icewm-themes/CMakeLists.txt
new file mode 100644
index 0000000..8a02935
--- /dev/null
+++ b/kwin-styles/icewm/icewm-themes/CMakeLists.txt
@@ -0,0 +1,21 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    titleAB.xpm titleAJ.xpm titleAM.xpm titleAP.xpm titleAQ.xpm
+    titleAR.xpm titleAS.xpm titleAT.xpm titleIB.xpm titleIJ.xpm
+    titleIM.xpm titleIQ.xpm titleIR.xpm titleIS.xpm titleIT.xpm
+    titleIP.xpm closeA.xpm closeI.xpm depthA.xpm depthI.xpm
+    maximizeA.xpm maximizeI.xpm menuButtonA.xpm menuButtonI.xpm
+    minimizeA.xpm minimizeI.xpm restoreA.xpm restoreI.xpm
+    rolldownA.xpm rolldownI.xpm rollupA.xpm rollupI.xpm
+    default.theme
+  DESTINATION ${DATA_INSTALL_DIR}/kwin/icewm-themes )
diff --git a/kwin-styles/kde1/CMakeLists.txt b/kwin-styles/kde1/CMakeLists.txt
new file mode 100644
index 0000000..dec7a69
--- /dev/null
+++ b/kwin-styles/kde1/CMakeLists.txt
@@ -0,0 +1,32 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES kde1.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_cde ##################################
+
+tde_add_kpart( kwin3_kde1 AUTOMOC
+  SOURCES kde1client.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/kstep/CMakeLists.txt b/kwin-styles/kstep/CMakeLists.txt
new file mode 100644
index 0000000..0344dd4
--- /dev/null
+++ b/kwin-styles/kstep/CMakeLists.txt
@@ -0,0 +1,32 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES kstep.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_kstep ###############################
+
+tde_add_kpart( kwin3_kstep AUTOMOC
+  SOURCES nextclient.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/openlook/CMakeLists.txt b/kwin-styles/openlook/CMakeLists.txt
new file mode 100644
index 0000000..6727bb4
--- /dev/null
+++ b/kwin-styles/openlook/CMakeLists.txt
@@ -0,0 +1,33 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${CMAKE_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES openlook.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_openlook ############################
+
+tde_add_kpart( kwin3_openlook AUTOMOC
+  SOURCES OpenLook.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/riscos/CMakeLists.txt b/kwin-styles/riscos/CMakeLists.txt
new file mode 100644
index 0000000..470b6f9
--- /dev/null
+++ b/kwin-styles/riscos/CMakeLists.txt
@@ -0,0 +1,52 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_definitions(
+  -DQT_PLUGIN
+)
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${CMAKE_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES riscos.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_riscos ###############################
+
+
+set( target kwin3_riscos )
+
+set( ${target}_SRCS
+  AboveButton.cpp Button.cpp
+  CloseButton.cpp
+  HelpButton.cpp
+  IconifyButton.cpp
+  LowerButton.cpp
+  Manager.cpp
+  MaximiseButton.cpp
+  Static.cpp
+  StickyButton.cpp
+)
+
+tde_add_kpart( ${target} AUTOMOC
+  SOURCES ${${target}_SRCS}
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/smooth-blend/CMakeLists.txt b/kwin-styles/smooth-blend/CMakeLists.txt
new file mode 100644
index 0000000..bfd4d79
--- /dev/null
+++ b/kwin-styles/smooth-blend/CMakeLists.txt
@@ -0,0 +1,12 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( client )
\ No newline at end of file
diff --git a/kwin-styles/smooth-blend/client/CMakeLists.txt b/kwin-styles/smooth-blend/client/CMakeLists.txt
new file mode 100644
index 0000000..09011c4
--- /dev/null
+++ b/kwin-styles/smooth-blend/client/CMakeLists.txt
@@ -0,0 +1,38 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( config )
+
+add_definitions(
+  -DQT_PLUGIN
+)
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES smoothblend.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_smoothblend ##########################
+
+tde_add_kpart( kwin3_smoothblend AUTOMOC
+  SOURCES smoothblend.cc
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/smooth-blend/client/config/CMakeLists.txt b/kwin-styles/smooth-blend/client/config/CMakeLists.txt
new file mode 100644
index 0000000..6f858e9
--- /dev/null
+++ b/kwin-styles/smooth-blend/client/config/CMakeLists.txt
@@ -0,0 +1,32 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_definitions(
+  -DQT_PLUGIN
+)
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### kwin_smoothblend_config (module) ##########
+
+tde_add_kpart( kwin_smoothblend_config AUTOMOC
+  SOURCES configdialog.ui smoothblendconfig.cc
+  LINK kdeui-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kwin-styles/system/CMakeLists.txt b/kwin-styles/system/CMakeLists.txt
new file mode 100644
index 0000000..cc79567
--- /dev/null
+++ b/kwin-styles/system/CMakeLists.txt
@@ -0,0 +1,32 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${CMAKE_CURRENT_BINARY_DIR}
+  ${TDE_INCLUDE_DIR}
+  ${TQT_INCLUDE_DIRS}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES system.desktop DESTINATION ${DATA_INSTALL_DIR}/kwin )
+
+##### kwin3_system ###############################
+
+tde_add_kpart( kwin3_system AUTOMOC
+  SOURCES systemclient.cpp
+  LINK kdecorations-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/kworldclock/CMakeLists.txt b/kworldclock/CMakeLists.txt
new file mode 100644
index 0000000..a255f2d
--- /dev/null
+++ b/kworldclock/CMakeLists.txt
@@ -0,0 +1,17 @@
+#################################################
+#
+#  (C) 2010 Serghei Amelian
+#  serghei (DOT) amelian (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( alt )
+add_subdirectory( bio )
+add_subdirectory( caida )
+add_subdirectory( caida_bw )
+add_subdirectory( mggd )
+add_subdirectory( rainfall )
diff --git a/kworldclock/alt/CMakeLists.txt b/kworldclock/alt/CMakeLists.txt
new file mode 100644
index 0000000..c65496f
--- /dev/null
+++ b/kworldclock/alt/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    1200.jpg
+    200.jpg
+    400.jpg
+    800.jpg
+    alt.desktop
+  DESTINATION "${DATA_INSTALL_DIR}/kworldclock/maps/alt" )
diff --git a/kworldclock/bio/CMakeLists.txt b/kworldclock/bio/CMakeLists.txt
new file mode 100644
index 0000000..4c6d195
--- /dev/null
+++ b/kworldclock/bio/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    1600.jpg
+    200.jpg
+    400.jpg
+    800.jpg
+    bio.desktop
+  DESTINATION "${DATA_INSTALL_DIR}/kworldclock/maps/bio" )
diff --git a/kworldclock/caida/CMakeLists.txt b/kworldclock/caida/CMakeLists.txt
new file mode 100644
index 0000000..7a7f576
--- /dev/null
+++ b/kworldclock/caida/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    1280.jpg
+    200.jpg
+    400.jpg
+    800.jpg
+    caida.desktop
+  DESTINATION "${DATA_INSTALL_DIR}/kworldclock/maps/caida" )
diff --git a/kworldclock/caida_bw/CMakeLists.txt b/kworldclock/caida_bw/CMakeLists.txt
new file mode 100644
index 0000000..26ee188
--- /dev/null
+++ b/kworldclock/caida_bw/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    1280.jpg
+    200.jpg
+    400.jpg
+    800.jpg
+    caida_bw.desktop
+  DESTINATION "${DATA_INSTALL_DIR}/kworldclock/maps/caida_bw" )
diff --git a/kworldclock/mggd/CMakeLists.txt b/kworldclock/mggd/CMakeLists.txt
new file mode 100644
index 0000000..42f6e89
--- /dev/null
+++ b/kworldclock/mggd/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    1440.jpg
+    200.jpg
+    400.jpg
+    800.jpg
+    mggd.desktop
+  DESTINATION "${DATA_INSTALL_DIR}/kworldclock/maps/mggd" )
diff --git a/kworldclock/rainfall/CMakeLists.txt b/kworldclock/rainfall/CMakeLists.txt
new file mode 100644
index 0000000..2cd781c
--- /dev/null
+++ b/kworldclock/rainfall/CMakeLists.txt
@@ -0,0 +1,18 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    1600.jpg
+    200.jpg
+    400.jpg
+    800.jpg
+    rainfall.desktop
+  DESTINATION "${DATA_INSTALL_DIR}/kworldclock/maps/rainfall" )
diff --git a/sounds/CMakeLists.txt b/sounds/CMakeLists.txt
new file mode 100644
index 0000000..4af42dd
--- /dev/null
+++ b/sounds/CMakeLists.txt
@@ -0,0 +1,15 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    KDE_Logout_new.wav
+    KDE_Startup_new.wav
+  DESTINATION ${SOUND_INSTALL_DIR} )
diff --git a/styles/CMakeLists.txt b/styles/CMakeLists.txt
new file mode 100644
index 0000000..ca32bd4
--- /dev/null
+++ b/styles/CMakeLists.txt
@@ -0,0 +1,13 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_subdirectory( dotnet )
+add_subdirectory( phase )
diff --git a/styles/dotnet/CMakeLists.txt b/styles/dotnet/CMakeLists.txt
new file mode 100644
index 0000000..cd00694
--- /dev/null
+++ b/styles/dotnet/CMakeLists.txt
@@ -0,0 +1,43 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_definitions(
+  -DQT_PLUGIN
+)
+
+include_directories(
+  ${TQT_INCLUDE_DIRS}
+  ${TDE_INCLUDE_DIR}
+  ${CMAKE_CURRENT_BINARY_DIR}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### other data ################################
+
+install( FILES dotnet.themerc DESTINATION ${DATA_INSTALL_DIR}/kstyle/themes )
+
+
+##### dotnet #####################################
+
+set( target dotnet )
+
+set( ${target}_SRCS
+  dotnet.cpp
+)
+
+tde_add_kpart( ${target} AUTOMOC
+  SOURCES ${${target}_SRCS}
+  LINK kdeui-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}/plugins/styles
+)
diff --git a/styles/phase/CMakeLists.txt b/styles/phase/CMakeLists.txt
new file mode 100644
index 0000000..c3c96bd
--- /dev/null
+++ b/styles/phase/CMakeLists.txt
@@ -0,0 +1,45 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+add_definitions(
+  -DQT_PLUGIN
+)
+
+include_directories(
+  ${TQT_INCLUDE_DIRS}
+  ${TDE_INCLUDE_DIR}
+  ${CMAKE_CURRENT_BINARY_DIR}
+)
+
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+add_subdirectory( config )
+
+##### other data ################################
+
+install( FILES phase.themerc DESTINATION ${DATA_INSTALL_DIR}/kstyle/themes )
+
+##### phasestyle #################################
+
+set( target phasestyle )
+
+set( ${target}_SRCS
+  phasestyle.cpp
+)
+
+tde_add_kpart( ${target} AUTOMOC
+  SOURCES ${${target}_SRCS}
+  LINK kdefx-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}/plugins/styles
+)
diff --git a/styles/phase/config/CMakeLists.txt b/styles/phase/config/CMakeLists.txt
new file mode 100644
index 0000000..fefcc9f
--- /dev/null
+++ b/styles/phase/config/CMakeLists.txt
@@ -0,0 +1,35 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+include_directories(
+  ${TQT_INCLUDE_DIRS}
+  ${TDE_INCLUDE_DIR}
+  ${CMAKE_CURRENT_BINARY_DIR}
+)
+
+link_directories(
+  ${TQT_LIBRARY_DIRS}
+)
+
+##### kstyle_phase_config ########################
+
+set( target kstyle_phase_config )
+
+set( ${target}_SRCS
+  phasestyleconfig.cpp
+  styledialog.ui
+)
+
+tde_add_kpart( ${target} AUTOMOC
+  SOURCES ${${target}_SRCS}
+  LINK kdeui-shared
+  DESTINATION ${PLUGIN_INSTALL_DIR}
+)
diff --git a/wallpapers/CMakeLists.txt b/wallpapers/CMakeLists.txt
new file mode 100644
index 0000000..1835a03
--- /dev/null
+++ b/wallpapers/CMakeLists.txt
@@ -0,0 +1,42 @@
+#################################################
+#
+#  (C) 2011 Golubev Alexander
+#  fatzer2 (AT) gmail.com
+#
+#  Improvements and feedback are welcome
+#
+#  This file is released under GPL >= 2
+#
+#################################################
+
+install( FILES
+    air.jpg air.jpg.desktop
+    alien-night.jpg alien-night.jpg.desktop
+    antique_chess.jpg antique_chess.jpg.desktop
+    Appropriately-Left-Handed-2.jpg
+    autumn_leaves.jpg autumn_leaves.jpg.desktop
+    blue_angle_swirl.jpg
+    bluegreencrisscross.jpg 
+    crystal_fire.png crystal_fire.png.desktop
+    curls_on_green.jpg curls_on_green.jpg.desktop
+    damselfly.jpg damselfly.jpg.desktop
+    ethais.png ethais.png.desktop
+    fulmine.jpg fulmine.jpg.desktop
+    gear-flowers.svgz gear-flowers.svgz.desktop
+    gold_crinkle.jpg
+    golden_dome.jpg golden_dome.jpg.desktop
+    kore.png kore.png.desktop
+    kraftwurm.jpg kraftwurm.jpg.desktop
+    kubical.png kubical.png.desktop
+    landscape_keltern.jpg landscape_keltern.jpg.desktop
+    mystical_rightturn.jpg mystical_rightturn.jpg.desktop
+    sepia_mountain.jpg sepia_mountain.jpg.desktop
+    storm_blue.jpg storm_blue.jpg.desktop
+    storm_green.jpg storm_green.jpg.desktop
+    sunset_field.jpg sunset_field.jpg.desktop
+    Superfluous-Organ-1.jpg
+    the_bay.jpg the_bay.jpg.desktop
+    The-Good-Times-1.jpg
+    vegetative_fog.jpg
+    Water01.jpg
+  DESTINATION ${WALLPAPER_INSTALL_DIR} )
